==> libcec_4.0.2+dfsg1.orig.tar.xz: libcec-libcec-4.0.2/src/libcec/devices/CECPlaybackDevice.h <==
#pragma once
/*
 * This file is part of the libCEC(R) library.
 *
 * libCEC(R) is Copyright (C) 2011-2015 Pulse-Eight Limited.  All rights reserved.
 * libCEC(R) is an original work, containing original code.
 *
 * libCEC(R) is a trademark of Pulse-Eight Limited.
 *
 * This program is dual-licensed; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 *
 *
 * Alternatively, you can license this library under a commercial license,
 * please contact Pulse-Eight Licensing for more information.
 *
 * For more information contact:
 * Pulse-Eight Licensing       <license@pulse-eight.com>
 *     http://www.pulse-eight.com/
 *     http://www.pulse-eight.net/
 */

#include "env.h"
#include "CECBusDevice.h"

namespace CEC
{
  class CCECPlaybackDevice : public CCECBusDevice
  {
  public:
    CCECPlaybackDevice(CCECProcessor *processor, cec_logical_address address, uint16_t iPhysicalAddress = CEC_INVALID_PHYSICAL_ADDRESS);
    virtual ~CCECPlaybackDevice(void) {};

    cec_deck_info GetDeckStatus(const cec_logical_address initiator);
    cec_deck_control_mode GetDeckControlMode(const cec_logical_address initiator);

    void SetDeckStatus(cec_deck_info deckStatus);
    void SetDeckControlMode(cec_deck_control_mode mode);

    bool TransmitDeckStatus(cec_logical_address dest, bool bIsReply);

    virtual void ResetDeviceStatus(void);

  protected:
    cec_deck_info         m_deckStatus;
    cec_deck_control_mode m_deckControlMode;
  };
}

==> libcec_7.1.1.orig.tar.xz: libcec-libcec-7.1.1/src/libcec/devices/CECPlaybackDevice.h <==
#pragma once
/*
 * This file is part of the libCEC(R) library.
 *
 * libCEC(R) is Copyright (C) 2011-2015 Pulse-Eight Limited.  All rights reserved.
 * libCEC(R) is an original work, containing original code.
 *
 * libCEC(R) is a trademark of Pulse-Eight Limited.
 *
 * This program is dual-licensed; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 *
 *
 * Alternatively, you can license this library under a commercial license,
 * please contact Pulse-Eight Licensing for more information.
 *
 * For more information contact:
 * Pulse-Eight Licensing       <license@pulse-eight.com>
 *     http://www.pulse-eight.com/
 *     http://www.pulse-eight.net/
 */

#include "env.h"
#include "CECBusDevice.h"

namespace CEC
{
  class CCECPlaybackDevice : public CCECBusDevice
  {
  public:
    CCECPlaybackDevice(CCECProcessor *processor, cec_logical_address address, uint16_t iPhysicalAddress = CEC_INVALID_PHYSICAL_ADDRESS);
    virtual ~CCECPlaybackDevice(void) {};

    cec_deck_info GetDeckStatus(const cec_logical_address initiator);
    cec_deck_control_mode GetDeckControlMode(const cec_logical_address initiator);

    void SetDeckStatus(cec_deck_info deckStatus);
    void SetDeckControlMode(cec_deck_control_mode mode);

    bool TransmitDeckStatus(cec_logical_address dest, bool bIsReply);

    virtual void ResetDeviceStatus(bool bClientUnregistered = false);;

  protected:
    cec_deck_info         m_deckStatus;
    cec_deck_control_mode m_deckControlMode;
  };
}
